ModelWithProblem

Trait ModelWithProblem 

pub trait ModelWithProblem {
    // Required methods
    fn vars(&self) -> Vec<Variable>;
    fn orig_vars(&self) -> Vec<Variable>;
    fn var(&self, var_id: VarId) -> Option<Variable>;
    fn n_vars(&self) -> usize;
    fn n_conss(&self) -> usize;
    fn find_cons(&self, name: &str) -> Option<Constraint>;
    fn conss(&self) -> Vec<Constraint>;
    fn cons_is_modifiable(&self, cons: &Constraint) -> bool;
    fn cons_is_removable(&self, cons: &Constraint) -> bool;
    fn cons_is_separated(&self, cons: &Constraint) -> bool;
    fn write(&self, path: &str, ext: &str) -> Result<(), Retcode>;
}
A trait for optimization models with a problem created.

Required Methods

fn vars(&self) -> Vec<Variable>

Returns a vector of all variables in the optimization model.

fn orig_vars(&self) -> Vec<Variable>

Returns a vector of all original variables in the optimization model.

fn var(&self, var_id: VarId) -> Option<Variable>

Returns the variable with the given ID, if it exists.

fn n_vars(&self) -> usize

Returns the number of variables in the optimization model.

fn n_conss(&self) -> usize

Returns the number of constraints in the optimization model.

fn find_cons(&self, name: &str) -> Option<Constraint>

Finds a constraint by name

fn conss(&self) -> Vec<Constraint>

Returns a vector of all constraints in the optimization model.

fn cons_is_modifiable(&self, cons: &Constraint) -> bool

Returns the modifiable flag of the given constraint

fn cons_is_removable(&self, cons: &Constraint) -> bool

Returns the removable flag of the given constraint

fn cons_is_separated(&self, cons: &Constraint) -> bool

Returns whether the constraint should be separated during LP processing

fn write(&self, path: &str, ext: &str) -> Result<(), Retcode>

Writes the optimization model to a file with the given path and extension.

Implementors