Variable

Struct Variable 

pub struct Variable { /* private fields */ }
A wrapper for a mutable reference to a SCIP variable.

Implementations

Source

impl Variable

pub fn inner(&self) -> *mut SCIP_VAR

Returns a raw pointer to the underlying ffi::SCIP_VAR struct.

pub fn index(&self) -> usize

Returns the index of the variable.

pub fn name(&self) -> String

Returns the name of the variable.

pub fn obj(&self) -> f64

Returns the objective coefficient of the variable.

pub fn lb(&self) -> f64

Returns the lower bound of the variable.

pub fn ub(&self) -> f64

Returns the upper bound of the variable.

pub fn lb_local(&self) -> f64

Returns the local lower bound of the variable.

pub fn ub_local(&self) -> f64

Returns the local upper bound of the variable.

pub fn var_type(&self) -> VarType

Returns the type of the variable.

pub fn status(&self) -> VarStatus

Returns the status of the variable.

pub fn col(&self) -> Option<Col>

Returns the column associated with the variable.

pub fn is_in_lp(&self) -> bool

Returns whether the variable is a column variable in the LP relaxation.

pub fn sol_val(&self) -> f64

Returns the solution value of the variable in the current node.

pub fn is_deleted(&self) -> bool

Returns whether the variable is deleted.

pub fn is_transformed(&self) -> bool

Returns whether the variable is transformed.

pub fn is_original(&self) -> bool

Returns whether the variable is original.

pub fn is_negated(&self) -> bool

Returns whether the variable is negated.

pub fn is_removable(&self) -> bool

Returns whether the variable is removable (due to aging in the LP).

pub fn is_trans_from_orig(&self) -> bool

Returns whether the variable is a directed counterpart of an original variable.

pub fn is_active(&self) -> bool

Returns whether the variable is active (i.e., neither fixed nor aggregated).

pub fn transformed(&self) -> Option<Variable>

Returns the trasnformed variable if it exists.