pub struct Variable { /* private fields */ }Expand description
A wrapper for a mutable reference to a SCIP variable.
Implementations
Sourceimpl Variable
impl Variable
Sourcepub fn inner(&self) -> *mut SCIP_VAR
pub fn inner(&self) -> *mut SCIP_VAR
Returns a raw pointer to the underlying ffi::SCIP_VAR struct.
Sourcepub fn is_in_lp(&self) -> bool
pub fn is_in_lp(&self) -> bool
Returns whether the variable is a column variable in the LP relaxation.
Sourcepub fn is_deleted(&self) -> bool
pub fn is_deleted(&self) -> bool
Returns whether the variable is deleted.
Sourcepub fn is_transformed(&self) -> bool
pub fn is_transformed(&self) -> bool
Returns whether the variable is transformed.
Sourcepub fn is_original(&self) -> bool
pub fn is_original(&self) -> bool
Returns whether the variable is original.
Sourcepub fn is_negated(&self) -> bool
pub fn is_negated(&self) -> bool
Returns whether the variable is negated.
Sourcepub fn is_removable(&self) -> bool
pub fn is_removable(&self) -> bool
Returns whether the variable is removable (due to aging in the LP).
Sourcepub fn is_trans_from_orig(&self) -> bool
pub fn is_trans_from_orig(&self) -> bool
Returns whether the variable is a directed counterpart of an original variable.
Sourcepub fn is_active(&self) -> bool
pub fn is_active(&self) -> bool
Returns whether the variable is active (i.e., neither fixed nor aggregated).
Sourcepub fn transformed(&self) -> Option<Variable>
pub fn transformed(&self) -> Option<Variable>
Returns the trasnformed variable if it exists.